public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: "Philippe Mathieu-Daudé" <philmd@redhat.com>
To: devel@edk2.groups.io
Cc: Laszlo Ersek <lersek@redhat.com>, Eric Dong <eric.dong@intel.com>
Subject: [PATCH v3 40/78] NetworkPkg/Ip6Dxe: Fix various typos
Date: Fri,  7 Feb 2020 02:07:53 +0100	[thread overview]
Message-ID: <20200207010831.9046-41-philmd@redhat.com> (raw)
In-Reply-To: <20200207010831.9046-1-philmd@redhat.com>

From: Antoine Coeur <coeur@gmx.fr>

Fix various typos in comments and documentation.

Cc: Jiaxin Wu <jiaxin.wu@intel.com>
Cc: Siyuan Fu <siyuan.fu@intel.com>
Cc: Maciej Rabeda <maciej.rabeda@intel.com>
Signed-off-by: Antoine Coeur <coeur@gmx.fr>
Reviewed-by: Philippe Mathieu-Daude <philmd@redhat.com>
Reviewed-by: Maciej Rabeda <maciej.rabeda@intel.com>
Signed-off-by: Philippe Mathieu-Daude <philmd@redhat.com>
---
 NetworkPkg/Ip6Dxe/Ip6ConfigImpl.h |  4 ++--
 NetworkPkg/Ip6Dxe/Ip6Driver.h     |  8 ++++----
 NetworkPkg/Ip6Dxe/Ip6If.h         |  4 ++--
 NetworkPkg/Ip6Dxe/Ip6Impl.h       |  8 ++++----
 NetworkPkg/Ip6Dxe/Ip6Input.h      |  6 +++---
 NetworkPkg/Ip6Dxe/Ip6Mld.h        |  2 +-
 NetworkPkg/Ip6Dxe/Ip6Nd.h         |  4 ++--
 NetworkPkg/Ip6Dxe/Ip6Route.h      | 10 +++++-----
 NetworkPkg/Ip6Dxe/Ip6Common.c     |  2 +-
 NetworkPkg/Ip6Dxe/Ip6ConfigImpl.c | 10 +++++-----
 NetworkPkg/Ip6Dxe/Ip6ConfigNv.c   |  6 +++---
 NetworkPkg/Ip6Dxe/Ip6Driver.c     | 12 ++++++------
 NetworkPkg/Ip6Dxe/Ip6Icmp.c       |  2 +-
 NetworkPkg/Ip6Dxe/Ip6If.c         | 10 +++++-----
 NetworkPkg/Ip6Dxe/Ip6Impl.c       | 10 +++++-----
 NetworkPkg/Ip6Dxe/Ip6Input.c      | 20 ++++++++++----------
 NetworkPkg/Ip6Dxe/Ip6Mld.c        |  8 ++++----
 NetworkPkg/Ip6Dxe/Ip6Nd.c         | 12 ++++++------
 NetworkPkg/Ip6Dxe/Ip6Output.c     |  2 +-
 NetworkPkg/Ip6Dxe/Ip6Route.c      |  6 +++---
 20 files changed, 73 insertions(+), 73 deletions(-)

diff --git a/NetworkPkg/Ip6Dxe/Ip6ConfigImpl.h b/NetworkPkg/Ip6Dxe/Ip6ConfigImpl.h
index bfe3bbe53875..1c2eede2ab21 100644
--- a/NetworkPkg/Ip6Dxe/Ip6ConfigImpl.h
+++ b/NetworkPkg/Ip6Dxe/Ip6ConfigImpl.h
@@ -1,5 +1,5 @@
 /** @file
-  Definitions for EFI IPv6 Configuartion Protocol implementation.
+  Definitions for EFI IPv6 Configuration Protocol implementation.
 
   Copyright (c) 2009 - 2018, Intel Corporation. All rights reserved.<BR>
 
@@ -210,7 +210,7 @@ struct _IP6_CONFIG_INSTANCE {
 /**
   Read the configuration data from variable storage according to the VarName and
   gEfiIp6ConfigProtocolGuid. It checks the integrity of variable data. If the
-  data is corrupted, it clears the variable data to ZERO. Othewise, it outputs the
+  data is corrupted, it clears the variable data to ZERO. Otherwise, it outputs the
   configuration data to IP6_CONFIG_INSTANCE.
 
   @param[in]      VarName  The pointer to the variable name
diff --git a/NetworkPkg/Ip6Dxe/Ip6Driver.h b/NetworkPkg/Ip6Dxe/Ip6Driver.h
index b048dafdccc5..007f687c6e25 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Driver.h
+++ b/NetworkPkg/Ip6Dxe/Ip6Driver.h
@@ -66,7 +66,7 @@ Ip6DriverEntryPoint (
   );
 
 //
-// Function prototypes for the Drivr Binding Protocol
+// Function prototypes for the Driver Binding Protocol
 //
 
 /**
@@ -98,7 +98,7 @@ Ip6DriverBindingSupported (
   @param[in]  RemainingDevicePath Optional parameter used to pick a specific child
                                   device to start.
 
-  @retval EFI_SUCCES              This driver is added to ControllerHandle.
+  @retval EFI_SUCCESS             This driver is added to ControllerHandle.
   @retval EFI_ALREADY_STARTED     This driver is already running on ControllerHandle.
   @retval other                   This driver does not support this device.
 
@@ -147,7 +147,7 @@ Ip6DriverBindingStop (
                                  is not NULL, then the I/O services are added to
                                  the existing child handle.
 
-  @retval EFI_SUCCES             The child handle was created with the I/O services.
+  @retval EFI_SUCCESS            The child handle was created with the I/O services.
   @retval EFI_OUT_OF_RESOURCES   There are not enough resources available to create
                                  the child.
   @retval other                  The child handle was not created.
@@ -166,7 +166,7 @@ Ip6ServiceBindingCreateChild (
   @param[in]  This               Protocol instance pointer.
   @param[in]  ChildHandle        Handle of the child to destroy.
 
-  @retval EFI_SUCCES             The I/O services were removed from the child
+  @retval EFI_SUCCESS            The I/O services were removed from the child
                                  handle.
   @retval EFI_UNSUPPORTED        The child handle does not support the I/O services
                                   that are being removed.
diff --git a/NetworkPkg/Ip6Dxe/Ip6If.h b/NetworkPkg/Ip6Dxe/Ip6If.h
index a8af4322eb93..ab43d8ea592a 100644
--- a/NetworkPkg/Ip6Dxe/Ip6If.h
+++ b/NetworkPkg/Ip6Dxe/Ip6If.h
@@ -1,5 +1,5 @@
 /** @file
-  Definition for IP6 pesudo interface structure.
+  Definition for IP6 pseudo interface structure.
 
   Copyright (c) 2009 - 2010, Intel Corporation. All rights reserved.<BR>
 
@@ -203,7 +203,7 @@ Ip6OnFrameReceived (
 
   @retval EFI_ALREADY_STARTED   There is already a pending receive request.
   @retval EFI_OUT_OF_RESOURCES  Failed to allocate resources to receive.
-  @retval EFI_SUCCESS           The recieve request has been started.
+  @retval EFI_SUCCESS           The receive request has been started.
 
 **/
 EFI_STATUS
diff --git a/NetworkPkg/Ip6Dxe/Ip6Impl.h b/NetworkPkg/Ip6Dxe/Ip6Impl.h
index d46ee600d5cc..8919e9448900 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Impl.h
+++ b/NetworkPkg/Ip6Dxe/Ip6Impl.h
@@ -139,7 +139,7 @@ struct _IP6_PROTOCOL {
 
   UINT8                     PrefixLength; // PrefixLength of the configured station address.
   //
-  // User's transmit/receive tokens, and received/deliverd packets
+  // User's transmit/receive tokens, and received/delivered packets
   //
   NET_MAP                   RxTokens;
   NET_MAP                   TxTokens;   // map between (User's Token, IP6_TXTOKE_WRAP)
@@ -412,7 +412,7 @@ EfiIp6GetModeData (
   @retval EFI_DEVICE_ERROR       An unexpected system or network error occurred. The EFI IPv6
                                  Protocol driver instance was not opened.
   @retval EFI_UNSUPPORTED        Default protocol specified through
-                                 Ip6ConfigData.DefaulProtocol isn't supported.
+                                 Ip6ConfigData.DefaultProtocol isn't supported.
 
 **/
 EFI_STATUS
@@ -470,7 +470,7 @@ EfiIp6Groups (
   the destination IPv6 address arithmetically. The gateway address must be on the same subnet as the
   configured station address.
 
-  The default route is added with Destination and PrefixLegth both set to all zeros. The
+  The default route is added with Destination and PrefixLength both set to all zeros. The
   default route matches all destination IPv6 addresses that do not match any other routes.
 
   All EFI IPv6 Protocol instances share a routing table.
@@ -642,7 +642,7 @@ EfiIp6Transmit (
   is signaled.
 
   Current Udp implementation creates an IP child for each Udp child.
-  It initates a asynchronous receive immediately whether or not
+  It initiates a asynchronous receive immediately whether or not
   there is no mapping. Therefore, disable the returning EFI_NO_MAPPING for now.
   To enable it, the following check must be performed:
 
diff --git a/NetworkPkg/Ip6Dxe/Ip6Input.h b/NetworkPkg/Ip6Dxe/Ip6Input.h
index 66ddf35ea4a6..76a4edb54c3c 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Input.h
+++ b/NetworkPkg/Ip6Dxe/Ip6Input.h
@@ -149,7 +149,7 @@ Ip6InstanceDeliverPacket (
   @retval EFI_SUCCESS            The packet was bypassed, and all buffers remain the same.
   @retval EFI_SUCCESS            The packet was protected.
   @retval EFI_ACCESS_DENIED      The packet was discarded.
-  @retval EFI_OUT_OF_RESOURCES   There are not suffcient resources to complete the operation.
+  @retval EFI_OUT_OF_RESOURCES   There are not sufficient resources to complete the operation.
   @retval EFI_BUFFER_TOO_SMALL   The number of non-empty blocks is bigger than the
                                  number of input data blocks when building a fragment table.
 
@@ -192,11 +192,11 @@ Ip6CleanAssembleTable (
 
 /**
   Demultiple the packet. the packet delivery is processed in two
-  passes. The first pass will enque a shared copy of the packet
+  passes. The first pass will enqueue a shared copy of the packet
   to each IP6 child that accepts the packet. The second pass will
   deliver a non-shared copy of the packet to each IP6 child that
   has pending receive requests. Data is copied if more than one
-  child wants to consume the packet bacause each IP child need
+  child wants to consume the packet because each IP child need
   its own copy of the packet to make changes.
 
   @param[in]  IpSb          The IP6 service instance that received the packet.
diff --git a/NetworkPkg/Ip6Dxe/Ip6Mld.h b/NetworkPkg/Ip6Dxe/Ip6Mld.h
index d907a15c6e65..89dd6c21fb64 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Mld.h
+++ b/NetworkPkg/Ip6Dxe/Ip6Mld.h
@@ -124,7 +124,7 @@ Ip6LeaveGroup (
 
   @retval EFI_ALREADY_STARTED   Wants to join the group, but is already a member of it.
   @retval EFI_OUT_OF_RESOURCES  Failed to allocate some resources.
-  @retval EFI_DEVICE_ERROR      Failed to set the group configuraton.
+  @retval EFI_DEVICE_ERROR      Failed to set the group configuration.
   @retval EFI_SUCCESS           Successfully updated the group setting.
   @retval EFI_NOT_FOUND         Tried to leave a group of whom it isn't a member.
 
diff --git a/NetworkPkg/Ip6Dxe/Ip6Nd.h b/NetworkPkg/Ip6Dxe/Ip6Nd.h
index 891a32d7d3ca..560dfa343782 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Nd.h
+++ b/NetworkPkg/Ip6Dxe/Ip6Nd.h
@@ -587,7 +587,7 @@ Ip6ProcessRouterAdvertise (
                                  the IP head removed.
 
   @retval EFI_INVALID_PARAMETER  The parameter is invalid.
-  @retval EFI_OUT_OF_RESOURCES   Insuffcient resources to complete the
+  @retval EFI_OUT_OF_RESOURCES   Insufficient resources to complete the
                                  operation.
   @retval EFI_SUCCESS            Successfully updated the route caches.
 
@@ -705,7 +705,7 @@ Ip6NdFasterTimerTicking (
 
 /**
   The heartbeat timer of ND module in 1 second. This time routine handles following
-  things: 1) maitain default router list; 2) maintain prefix options;
+  things: 1) maintain default router list; 2) maintain prefix options;
   3) maintain route caches.
 
   @param[in]  IpSb              The IP6 service binding instance.
diff --git a/NetworkPkg/Ip6Dxe/Ip6Route.h b/NetworkPkg/Ip6Dxe/Ip6Route.h
index 9ddc1ab7bc53..af20dbb149b0 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Route.h
+++ b/NetworkPkg/Ip6Dxe/Ip6Route.h
@@ -1,5 +1,5 @@
 /** @file
-  EFI IP6 route table and route cache table defintions.
+  EFI IP6 route table and route cache table definitions.
 
   Copyright (c) 2009 - 2010, Intel Corporation. All rights reserved.<BR>
 
@@ -110,7 +110,7 @@ Ip6FreeRouteCacheEntry (
 
 /**
   Find a route cache with the destination and source address. This is
-  used by the ICMPv6 redirect messasge process.
+  used by the ICMPv6 redirect message process.
 
   @param[in]  RtTable       The route table to search the cache for.
   @param[in]  Dest          The destination address.
@@ -181,7 +181,7 @@ Ip6CleanRouteTable (
   @param[in]  GatewayAddress  The next hop address. This is optional parameter
                               that may be NULL.
 
-  @return NULL if it failed to allocate memeory. Otherwise, the newly created route entry.
+  @return NULL if it failed to allocate memory. Otherwise, the newly created route entry.
 
 **/
 IP6_ROUTE_ENTRY *
@@ -201,7 +201,7 @@ Ip6CreateRouteEntry (
   2. The local route entries have precedence over the default route entry.
 
   @param[in]  RtTable       The route table to search from.
-  @param[in]  Destination   The destionation address to search. If NULL, search
+  @param[in]  Destination   The destination address to search. If NULL, search
                             the route table by NextHop.
   @param[in]  NextHop       The next hop address. If NULL, search the route table
                             by Destination.
@@ -260,7 +260,7 @@ Ip6AddRoute (
 
   @retval EFI_SUCCESS           Successfully removed the route entry.
   @retval EFI_NOT_FOUND         There is no route entry in the table with that
-                                properity.
+                                property.
 
 **/
 EFI_STATUS
diff --git a/NetworkPkg/Ip6Dxe/Ip6Common.c b/NetworkPkg/Ip6Dxe/Ip6Common.c
index 4ae04f258ffc..840fff0e72e5 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Common.c
+++ b/NetworkPkg/Ip6Dxe/Ip6Common.c
@@ -214,7 +214,7 @@ Ip6CreateLinkLocalAddr (
   }
 
   //
-  // Get the interface id if it is manully configured.
+  // Get the interface id if it is manually configured.
   //
   Ip6Config = &IpSb->Ip6ConfigInstance.Ip6Config;
   DataSize  = sizeof (EFI_IP6_CONFIG_INTERFACE_ID);
diff --git a/NetworkPkg/Ip6Dxe/Ip6ConfigNv.c b/NetworkPkg/Ip6Dxe/Ip6ConfigNv.c
index aac665d3d427..a0727d2666e9 100644
--- a/NetworkPkg/Ip6Dxe/Ip6ConfigNv.c
+++ b/NetworkPkg/Ip6Dxe/Ip6ConfigNv.c
@@ -407,7 +407,7 @@ Ip6CreateOpCode (
 
 /**
   This function converts the different format of address list to string format and
-  then generates the corresponding text opcode to illustarate the address info in
+  then generates the corresponding text opcode to illustrate the address info in
   IP6 configuration page. Currently, the following formats are supported:
   EFI_IP6_ADDRESS_INFO AddressType: Ip6ConfigNvHostAddress;
   EFI_IPv6_ADDRESS     AddressType: Ip6ConfigNvGatewayAddress and Ip6ConfigNvDnsAddress;
@@ -1470,7 +1470,7 @@ Ip6FormExtractConfig (
   @param[out] Progress       A pointer to a string filled in with the
                              offset of the most recent '&' before the
                              first failing name / value pair (or the
-                             beginn ing of the string if the failure
+                             beginning of the string if the failure
                              is in the first name / value pair) or
                              the terminating NULL if all was
                              successful.
@@ -1622,7 +1622,7 @@ Ip6GetCurrentSetting (
   }
 
   //
-  // Get gateway adderss list.
+  // Get gateway address list.
   //
   if (Data != NULL) {
     FreePool (Data);
diff --git a/NetworkPkg/Ip6Dxe/Ip6Driver.c b/NetworkPkg/Ip6Dxe/Ip6Driver.c
index 63d8428dbced..7c13d6a3d4cc 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Driver.c
+++ b/NetworkPkg/Ip6Dxe/Ip6Driver.c
@@ -498,7 +498,7 @@ Ip6CreateService (
   @param[in]  RemainingDevicePath Optional parameter used to pick a specific child
                                   device to start.
 
-  @retval EFI_SUCCES              This driver is added to ControllerHandle.
+  @retval EFI_SUCCESS             This driver is added to ControllerHandle.
   @retval EFI_ALREADY_STARTED     This driver is already running on ControllerHandle.
   @retval other                   This driver does not support this device.
 
@@ -547,7 +547,7 @@ Ip6DriverBindingStart (
   Ip6Cfg  = &IpSb->Ip6ConfigInstance.Ip6Config;
 
   //
-  // Install the Ip6ServiceBinding Protocol onto ControlerHandle
+  // Install the Ip6ServiceBinding Protocol onto ControllerHandle
   //
   Status = gBS->InstallMultipleProtocolInterfaces (
                   &ControllerHandle,
@@ -823,7 +823,7 @@ Ip6DriverBindingStop (
                                  is not NULL, then the I/O services are added to
                                  the existing child handle.
 
-  @retval EFI_SUCCES             The child handle was created with the I/O services.
+  @retval EFI_SUCCESS            The child handle was created with the I/O services.
   @retval EFI_OUT_OF_RESOURCES   There are not enough resources available to create
                                  the child.
   @retval other                  The child handle was not created.
@@ -925,7 +925,7 @@ Ip6ServiceBindingCreateChild (
   @param[in]  This               Protocol instance pointer.
   @param[in]  ChildHandle        Handle of the child to destroy.
 
-  @retval EFI_SUCCES             The I/O services were removed from the child
+  @retval EFI_SUCCESS            The I/O services were removed from the child
                                  handle.
   @retval EFI_UNSUPPORTED        The child handle does not support the I/O services
                                   that are being removed.
@@ -1005,14 +1005,14 @@ Ip6ServiceBindingDestroyChild (
   // Uninstall the IP6 protocol first. Many thing happens during
   // this:
   // 1. The consumer of the IP6 protocol will be stopped if it
-  // opens the protocol BY_DRIVER. For eaxmple, if MNP driver is
+  // opens the protocol BY_DRIVER. For example, if MNP driver is
   // stopped, IP driver's stop function will be called, and uninstall
   // EFI_IP6_PROTOCOL will trigger the UDP's stop function. This
   // makes it possible to create the network stack bottom up, and
   // stop it top down.
   // 2. the upper layer will recycle the received packet. The recycle
   // event's TPL is higher than this function. The recycle events
-  // will be called back before preceeding. If any packets not recycled,
+  // will be called back before preceding. If any packets not recycled,
   // that means there is a resource leak.
   //
   gBS->RestoreTPL (OldTpl);
diff --git a/NetworkPkg/Ip6Dxe/Ip6Icmp.c b/NetworkPkg/Ip6Dxe/Ip6Icmp.c
index bf9b17d907ef..d43121e4cb9e 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Icmp.c
+++ b/NetworkPkg/Ip6Dxe/Ip6Icmp.c
@@ -300,7 +300,7 @@ Ip6ProcessIcmpError (
   }
 
   //
-  // Notify the upper-layer process that an ICMPv6 eror message is received.
+  // Notify the upper-layer process that an ICMPv6 error message is received.
   //
   IP6_GET_CLIP_INFO (Packet)->Status = EFI_ICMP_ERROR;
   return Ip6Demultiplex (IpSb, Head, Packet);
diff --git a/NetworkPkg/Ip6Dxe/Ip6If.c b/NetworkPkg/Ip6Dxe/Ip6If.c
index 956c05c396aa..5b469710572c 100644
--- a/NetworkPkg/Ip6Dxe/Ip6If.c
+++ b/NetworkPkg/Ip6Dxe/Ip6If.c
@@ -1,5 +1,5 @@
 /** @file
-  Implement IP6 pesudo interface.
+  Implement IP6 pseudo interface.
 
   Copyright (c) 2009 - 2018, Intel Corporation. All rights reserved.<BR>
 
@@ -160,7 +160,7 @@ Ip6SetAddress (
 
 
   //
-  // Node should delay joining the solicited-node mulitcast address by a random delay
+  // Node should delay joining the solicited-node multicast address by a random delay
   // between 0 and MAX_RTR_SOLICITATION_DELAY (1 second).
   // Thus queue the address to be processed in Duplicate Address Detection module
   // after the delay time (in milliseconds).
@@ -497,7 +497,7 @@ Ip6OnFrameReceivedDpc (
   }
 
   //
-  // Wrap the frame in a net buffer then deliever it to IP input.
+  // Wrap the frame in a net buffer then deliver it to IP input.
   // IP will reassemble the packet, and deliver it to upper layer
   //
   Netfrag.Len  = MnpRxData->DataLength;
@@ -548,7 +548,7 @@ Ip6OnFrameReceived (
 
   @retval EFI_ALREADY_STARTED   There is already a pending receive request.
   @retval EFI_OUT_OF_RESOURCES  Failed to allocate resource to receive.
-  @retval EFI_SUCCESS           The recieve request has been started.
+  @retval EFI_SUCCESS           The receive request has been started.
 
 **/
 EFI_STATUS
@@ -575,7 +575,7 @@ Ip6ReceiveFrame (
 }
 
 /**
-  Callback funtion when frame transmission is finished. It will
+  Callback function when frame transmission is finished. It will
   call the frame owner's callback function to tell it the result.
 
   @param[in]  Context        Context which points to the token.
diff --git a/NetworkPkg/Ip6Dxe/Ip6Impl.c b/NetworkPkg/Ip6Dxe/Ip6Impl.c
index 80862bfe9d09..826a5c252f1a 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Impl.c
+++ b/NetworkPkg/Ip6Dxe/Ip6Impl.c
@@ -288,7 +288,7 @@ Ip6IsIllegalProtocol (
 }
 
 /**
-  Intiialize the IP6_PROTOCOL structure to the unconfigured states.
+  Initialize the IP6_PROTOCOL structure to the unconfigured states.
 
   @param[in]       IpSb                   The IP6 service instance.
   @param[in, out]  IpInstance             The IP6 child instance.
@@ -604,7 +604,7 @@ Ip6ServiceConfigMnp (
   @retval EFI_DEVICE_ERROR       An unexpected system or network error occurred. The EFI IPv6
                                  Protocol driver instance was not opened.
   @retval EFI_UNSUPPORTED        Default protocol specified through
-                                 Ip6ConfigData.DefaulProtocol isn't supported.
+                                 Ip6ConfigData.DefaultProtocol isn't supported.
 
 **/
 EFI_STATUS
@@ -787,7 +787,7 @@ EfiIp6Groups (
   the destination IPv6 address arithmetically. The gateway address must be on the same subnet as the
   configured station address.
 
-  The default route is added with Destination and PrefixLegth both set to all zeros. The
+  The default route is added with Destination and PrefixLength both set to all zeros. The
   default route matches all destination IPv6 addresses that do not match any other routes.
 
   All EFI IPv6 Protocol instances share a routing table.
@@ -1001,7 +1001,7 @@ EfiIp6Neighbors (
   @param[in]  Map                The container of either user's transmit or receive
                                  token.
   @param[in]  Item               Current item to check against.
-  @param[in]  Context            The Token to check againist.
+  @param[in]  Context            The Token to check against.
 
   @retval EFI_ACCESS_DENIED      The token or event has already been enqueued in IP
   @retval EFI_SUCCESS            The current item isn't the same token/event as the
@@ -1449,7 +1449,7 @@ EfiIp6Transmit (
   is signaled.
 
   Current Udp implementation creates an IP child for each Udp child.
-  It initates a asynchronous receive immediately no matter whether
+  It initiates a asynchronous receive immediately no matter whether
   there is no mapping or not. Therefore, disable the returning EFI_NO_MAPPING for now.
   To enable it, the following check must be performed:
 
diff --git a/NetworkPkg/Ip6Dxe/Ip6Input.c b/NetworkPkg/Ip6Dxe/Ip6Input.c
index 57a52326e1bf..c42baa35b6b6 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Input.c
+++ b/NetworkPkg/Ip6Dxe/Ip6Input.c
@@ -319,7 +319,7 @@ Ip6Reassemble (
     }
 
     //
-    // Backup the first fragment in case the reasembly of that packet fail.
+    // Backup the first fragment in case the reassembly of that packet fail.
     //
     Duplicate = NetbufDuplicate (Packet, NULL, sizeof (EFI_IP6_HEADER));
     if (Duplicate == NULL) {
@@ -371,7 +371,7 @@ Ip6Reassemble (
   //
   // Deliver the whole packet if all the fragments received.
   // All fragments received if:
-  //  1. received the last one, so, the totoal length is know
+  //  1. received the last one, so, the total length is known
   //  2. received all the data. If the last fragment on the
   //     queue ends at the total length, all data is received.
   //
@@ -380,7 +380,7 @@ Ip6Reassemble (
     RemoveEntryList (&Assemble->Link);
 
     //
-    // If the packet is properly formated, the last fragment's End
+    // If the packet is properly formatted, the last fragment's End
     // equals to the packet's total length. Otherwise, the packet
     // is a fake, drop it now.
     //
@@ -396,7 +396,7 @@ Ip6Reassemble (
     //
     // This TmpPacket is used to hold the unfragmentable part, i.e.,
     // the IPv6 header and the unfragmentable extension headers. Be noted that
-    // the Fragment Header is exluded.
+    // the Fragment Header is excluded.
     //
     TmpPacket = NetbufGetFragment (Fragment, 0, This->HeadLen, 0);
     ASSERT (TmpPacket != NULL);
@@ -489,7 +489,7 @@ Ip6IpSecFree (
   @retval EFI_SUCCESS            The packet was bypassed, and all buffers remain the same.
   @retval EFI_SUCCESS            The packet was protected.
   @retval EFI_ACCESS_DENIED      The packet was discarded.
-  @retval EFI_OUT_OF_RESOURCES   There are not suffcient resources to complete the operation.
+  @retval EFI_OUT_OF_RESOURCES   There are not sufficient resources to complete the operation.
   @retval EFI_BUFFER_TOO_SMALL   The number of non-empty blocks is bigger than the
                                  number of input data blocks when building a fragment table.
 
@@ -718,7 +718,7 @@ Ip6IpSecProcessPacket (
   @param[in, out] Packet        The received IP6 packet to be processed.
   @param[in]      Flag          The link layer flag for the packet received, such
                                 as multicast.
-  @param[out]     Payload       The pointer to the payload of the recieved packet.
+  @param[out]     Payload       The pointer to the payload of the received packet.
                                 it starts from the first byte of the extension header.
   @param[out]     LastHead      The pointer of NextHeader of the last extension
                                 header processed by IP6.
@@ -1070,7 +1070,7 @@ Ip6AcceptFrame (
 
   //
   // Packet may have been changed. The ownership of the packet
-  // is transfered to the packet process logic.
+  // is transferred to the packet process logic.
   //
   Head  = Packet->Ip.Ip6;
   IP6_GET_CLIP_INFO (Packet)->Status = EFI_SUCCESS;
@@ -1283,7 +1283,7 @@ Ip6InstanceFrameAcceptable (
   Proto  = NULL;
 
   //
-  // Dirty trick for the Tiano UEFI network stack implmentation. If
+  // Dirty trick for the Tiano UEFI network stack implementation. If
   // ReceiveTimeout == -1, the receive of the packet for this instance
   // is disabled. The UEFI spec don't have such captibility. We add
   // this to improve the performance because IP will make a copy of
@@ -1428,7 +1428,7 @@ Ip6InstanceEnquePacket (
   }
 
   //
-  // Enque a shared copy of the packet.
+  // Enqueue a shared copy of the packet.
   //
   Clone = NetbufClone (Packet);
 
@@ -1661,7 +1661,7 @@ Ip6Demultiplex (
   INTN                      Enqueued;
 
   //
-  // Two pass delivery: first, enque a shared copy of the packet
+  // Two pass delivery: first, enqueue a shared copy of the packet
   // to each instance that accept the packet.
   //
   Enqueued = 0;
diff --git a/NetworkPkg/Ip6Dxe/Ip6Mld.c b/NetworkPkg/Ip6Dxe/Ip6Mld.c
index b7a882b25975..ba12089dee25 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Mld.c
+++ b/NetworkPkg/Ip6Dxe/Ip6Mld.c
@@ -383,7 +383,7 @@ Ip6InitMld (
 
   @retval EFI_OUT_OF_RESOURCES      There are not sufficient resources to complete
                                     the operation.
-  @retval EFI_SUCESS                The address is added to the group address array.
+  @retval EFI_SUCCESS               The address is added to the group address array.
 
 **/
 EFI_STATUS
@@ -496,8 +496,8 @@ Ip6JoinGroup (
   }
 
   //
-  // Repeat the report once or twcie after short delays [Unsolicited Report Interval] (default:10s)
-  // Simulate this operation as a Multicast-Address-Specific Query was received for that addresss.
+  // Repeat the report once or twice after short delays [Unsolicited Report Interval] (default:10s)
+  // Simulate this operation as a Multicast-Address-Specific Query was received for that address.
   //
   Group = Ip6CreateMldEntry (IpSb, Address, IP6_UNSOLICITED_REPORT_INTERVAL);
   if (Group == NULL) {
@@ -604,7 +604,7 @@ Ip6LeaveGroup (
 
   @retval EFI_ALREADY_STARTED   Wants to join the group, but is already a member of it
   @retval EFI_OUT_OF_RESOURCES  Failed to allocate sufficient resources.
-  @retval EFI_DEVICE_ERROR      Failed to set the group configuraton.
+  @retval EFI_DEVICE_ERROR      Failed to set the group configuration.
   @retval EFI_SUCCESS           Successfully updated the group setting.
   @retval EFI_NOT_FOUND         Try to leave the group which it isn't a member.
 
diff --git a/NetworkPkg/Ip6Dxe/Ip6Nd.c b/NetworkPkg/Ip6Dxe/Ip6Nd.c
index 67d7022a7673..4288ef02dd46 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Nd.c
+++ b/NetworkPkg/Ip6Dxe/Ip6Nd.c
@@ -1645,7 +1645,7 @@ Ip6ProcessNeighborSolicit (
   //
   // Sends a Neighbor Advertisement as response.
   // Set the Router flag to zero since the node is a host.
-  // If the source address of the solicitation is unspeicifed, and target address
+  // If the source address of the solicitation is unspecified, and target address
   // is one of the maintained address, reply a unsolicited multicast advertisement.
   //
   if (IsDAD && IsMaintained) {
@@ -2087,7 +2087,7 @@ Ip6ProcessRouterAdvertise (
   }
 
   //
-  // If an valid router advertisment is received, stops router solicitation.
+  // If an valid router advertisement is received, stops router solicitation.
   //
   IpSb->RouterAdvertiseReceived = TRUE;
 
@@ -2251,7 +2251,7 @@ Ip6ProcessRouterAdvertise (
           //
           if (!Ip6IsOneOfSetAddress (IpSb, &StatelessAddress, NULL, NULL)) {
             //
-            // And also not in the DAD process, check its uniqeness firstly.
+            // And also not in the DAD process, check its uniqueness firstly.
             //
             if (Ip6FindDADEntry (IpSb, &StatelessAddress, NULL) == NULL) {
               Status = Ip6SetAddress (
@@ -2303,7 +2303,7 @@ Ip6ProcessRouterAdvertise (
 
           } else if (PrefixList->ValidLifetime <= 7200) {
             //
-            // If RemainingLifetime is less than or equls to 2 hours, ignore the
+            // If RemainingLifetime is less than or equals to 2 hours, ignore the
             // Prefix Information option with regards to the valid lifetime.
             // TODO: If this option has been authenticated, set the valid lifetime.
             //
@@ -2365,7 +2365,7 @@ Ip6ProcessRouterAdvertise (
                                  the IP head removed.
 
   @retval EFI_INVALID_PARAMETER  The parameter is invalid.
-  @retval EFI_OUT_OF_RESOURCES   Insuffcient resources to complete the
+  @retval EFI_OUT_OF_RESOURCES   Insufficient resources to complete the
                                  operation.
   @retval EFI_SUCCESS            Successfully updated the route caches.
 
@@ -3069,7 +3069,7 @@ Ip6NdFasterTimerTicking (
 
 /**
   The heartbeat timer of ND module in 1 second. This time routine handles following
-  things: 1) maitain default router list; 2) maintain prefix options;
+  things: 1) maintain default router list; 2) maintain prefix options;
   3) maintain route caches.
 
   @param[in]  IpSb              The IP6 service binding instance.
diff --git a/NetworkPkg/Ip6Dxe/Ip6Output.c b/NetworkPkg/Ip6Dxe/Ip6Output.c
index 6ab4459bab9c..2a2eae4b854f 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Output.c
+++ b/NetworkPkg/Ip6Dxe/Ip6Output.c
@@ -870,7 +870,7 @@ Ip6Output (
 
     for (Index = 0, Offset = 0, PacketLen = Mtu; Index < Num; Index++) {
       //
-      // Get fragment from the Packet, append UnFragnmentLen spare buffer
+      // Get fragment from the Packet, append UnFragmentLen spare buffer
       // before the fragmented data, the corresponding data is filled in later.
       //
       Fragment = NetbufGetFragment (Packet, Offset, PacketLen, UnFragmentLen);
diff --git a/NetworkPkg/Ip6Dxe/Ip6Route.c b/NetworkPkg/Ip6Dxe/Ip6Route.c
index c8d79cd6dbcc..c24361d2957c 100644
--- a/NetworkPkg/Ip6Dxe/Ip6Route.c
+++ b/NetworkPkg/Ip6Dxe/Ip6Route.c
@@ -44,7 +44,7 @@ Ip6RouteCacheHash (
   @param[in]  GatewayAddress  The next hop address. This is an optional parameter
                               that may be NULL.
 
-  @return NULL if failed to allocate memeory; otherwise, the newly created route entry.
+  @return NULL if failed to allocate memory; otherwise, the newly created route entry.
 
 **/
 IP6_ROUTE_ENTRY *
@@ -105,7 +105,7 @@ Ip6FreeRouteEntry (
   2. The local route entries have precedence over the default route entry.
 
   @param[in]  RtTable       The route table to search from.
-  @param[in]  Destination   The destionation address to search. If NULL, search
+  @param[in]  Destination   The destination address to search. If NULL, search
                             the route table by NextHop.
   @param[in]  NextHop       The next hop address. If NULL, search the route table
                             by Destination.
@@ -210,7 +210,7 @@ Ip6FreeRouteCacheEntry (
 
 /**
   Find a route cache with the destination and source address. This is
-  used by the ICMPv6 redirect messasge process.
+  used by the ICMPv6 redirect message process.
 
   @param[in]  RtTable       The route table to search the cache for.
   @param[in]  Dest          The destination address.
diff --git a/NetworkPkg/Ip6Dxe/Ip6ConfigImpl.c b/NetworkPkg/Ip6Dxe/Ip6ConfigImpl.c
index 6efed37a4d04..eb2a80b64f15 100644
--- a/NetworkPkg/Ip6Dxe/Ip6ConfigImpl.c
+++ b/NetworkPkg/Ip6Dxe/Ip6ConfigImpl.c
@@ -101,7 +101,7 @@ Ip6ConfigOnPolicyChanged (
     }
 
     //
-    // All IPv6 children that use global unicast address as it's source address
+    // All IPv6 children that use global unicast address as its source address
     // should be destroyed now. The survivers are those use the link-local address
     // or the unspecified address as the source address.
     // TODO: Conduct a check here.
@@ -335,7 +335,7 @@ Ip6ConfigSignalEvent (
 /**
   Read the configuration data from variable storage according to the VarName and
   gEfiIp6ConfigProtocolGuid. It checks the integrity of variable data. If the
-  data is corrupted, it clears the variable data to ZERO. Othewise, it outputs the
+  data is corrupted, it clears the variable data to ZERO. Otherwise, it outputs the
   configuration data to IP6_CONFIG_INSTANCE.
 
   @param[in]      VarName  The pointer to the variable name
@@ -612,7 +612,7 @@ Ip6ConfigGetIfInfo (
 }
 
 /**
-  The work function for EfiIp6ConfigSetData() to set the alternative inteface ID
+  The work function for EfiIp6ConfigSetData() to set the alternative interface ID
   for the communication device managed by this IP6Config instance, if the link local
   IPv6 addresses generated from the interface ID based on the default source the
   EFI IPv6 Protocol uses is a duplicate address.
@@ -915,7 +915,7 @@ Ip6ManualAddrDadCallback (
                                 under the current policy.
   @retval EFI_INVALID_PARAMETER One or more fields in Data is invalid.
   @retval EFI_OUT_OF_RESOURCES  Fail to allocate resource to complete the operation.
-  @retval EFI_NOT_READY         An asynchrous process is invoked to set the specified
+  @retval EFI_NOT_READY         An asynchronous process is invoked to set the specified
                                 configuration data, and the process is not finished.
   @retval EFI_ABORTED           The manual addresses to be set equal current
                                 configuration.
@@ -2034,7 +2034,7 @@ EfiIp6ConfigSetData (
     }
   } else {
     //
     // Another asynchornous process is on the way.
     //
     Status = EFI_ACCESS_DENIED;
   }
@@ -2034,7 +2034,7 @@ EfiIp6ConfigSetData (
   } else {
     //
-    // Another asynchornous process is on the way.
+    // Another asynchronous process is on the way.
     //
     Status = EFI_ACCESS_DENIED;
-- 
2.21.1


  parent reply	other threads:[~2020-02-07  1:40 UTC|newest]

Thread overview: 84+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2020-02-07  1:07 [PATCH v3 00/78] Fix a bunch of typos (part 1) Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 01/78] CryptoPkg/OpensslLib: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 02/78] EmbeddedPkg/VirtualKeyboard: Fix a typo in EFI_INVALID_PARAMETER Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 03/78] EmbeddedPkg/VirtualKeyboard: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 04/78] EmulatorPkg/Sec: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 05/78] EmulatorPkg/Unix: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 06/78] EmulatorPkg/Win: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 07/78] FatPkg/EnhancedFatDxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 08/78] FatPkg/FatPei: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 09/78] MdeModulePkg/Application: Improve French translation Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 10/78] MdeModulePkg/Application: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 11/78] MdeModulePkg/Bus/Ata: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 12/78] MdeModulePkg/Bus/I2c: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 13/78] MdeModulePkg/Bus/Isa: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 14/78] MdeModulePkg/Bus/Scsi: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 15/78] MdeModulePkg/Bus/Sd: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 16/78] MdeModulePkg/Core/Pei: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 17/78] MdeModulePkg/Core/PiSmmCore: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 18/78] MdeModulePkg/UsbBusDxe: Fix a typo Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 19/78] MdeModulePkg/UsbMass: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 20/78] MdeModulePkg/UsbMouse: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 21/78] MdeModulePkg/UsbBus: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 22/78] MdeModulePkg/Usb: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 23/78] MdePkg/IndustryStandard: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 24/78] MdePkg/Library/Dxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 25/78] MdePkg/Library/Pci: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 26/78] MdePkg/Library/Smm: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 27/78] MdePkg/Ppi: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 28/78] MdePkg/Register: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 29/78] NetworkPkg: Fix a typo Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 30/78] NetworkPkg/ArpDxe: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 31/78] NetworkPkg/Dhcp4Dxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 32/78] NetworkPkg/Dhcp6Dxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 33/78] NetworkPkg/DnsDxe: Fix a typo Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 34/78] NetworkPkg/DnsDxe: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 35/78] NetworkPkg/DpcDxe: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 36/78] NetworkPkg/HttpBootDxe: Fix a typo in variable name Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 37/78] NetworkPkg/HttpBootDxe: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 38/78] NetworkPkg/HttpDxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 39/78] NetworkPkg/Ip4Dxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` Philippe Mathieu-Daudé [this message]
2020-02-07  1:07 ` [PATCH v3 41/78] NetworkPkg/IScsiDxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 42/78] NetworkPkg/Library: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 43/78] NetworkPkg/MnpDxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 44/78] NetworkPkg/Mtftp4Dxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 45/78] NetworkPkg/Mtftp6Dxe: " Philippe Mathieu-Daudé
2020-02-07  1:07 ` [PATCH v3 46/78] NetworkPkg/SnpDxe: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 47/78] NetworkPkg/TcpDxe/Sock: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 48/78] NetworkPkg/TcpDxe/Tcp: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 49/78] NetworkPkg/Tls: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 50/78] NetworkPkg/Udp4Dxe: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 51/78] NetworkPkg/Udp6Dxe: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 52/78] NetworkPkg/UefiPxeBcDxe: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 53/78] NetworkPkg/VlanConfigDxe: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 54/78] OvmfPkg/Acpi: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 55/78] OvmfPkg/Csm: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 56/78] OvmfPkg/Csm/LegacyBios: Fix a typo Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 57/78] OvmfPkg/Qemu: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 58/78] OvmfPkg/Virtio: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 59/78] OvmfPkg/Xen: Fix a typo Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 60/78] OvmfPkg/Xen: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 61/78] PcAtChipsetPkg: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 62/78] SecurityPkg: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 63/78] SecurityPkg/Hash2DxeCrypto: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 64/78] SecurityPkg/Library/Tpm: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 65/78] SecurityPkg/Tcg: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 66/78] SecurityPkg/VariableAuthenticated: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 67/78] ShellPkg/Application: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 68/78] ShellPkg/DynamicCommand: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 69/78] SignedCapsulePkg: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 70/78] SignedCapsulePkg/Universal: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 71/78] SourceLevelDebugPkg/DebugAgent: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 72/78] SourceLevelDebugPkg/DebugCommunicationLib: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 73/78] SourceLevelDebugPkg: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 74/78] StandaloneMmPkg: Fix a typo Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 75/78] StandaloneMmPkg: Fix few typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 76/78] UefiCpuPkg/CpuDxe: " Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 77/78] UefiCpuPkg/PiSmm: Fix various typos Philippe Mathieu-Daudé
2020-02-07  1:08 ` [PATCH v3 78/78] UefiCpuPkg/Smm: " Philippe Mathieu-Daudé
2020-02-07 10:51 ` [PATCH v3 00/78] Fix a bunch of typos (part 1) Laszlo Ersek
2020-02-10 22:54   ` [edk2-devel] " Laszlo Ersek
2020-02-11 12:12     ` Philippe Mathieu-Daudé
2020-02-12 12:02       ` Laszlo Ersek
2020-02-12 17:01     ` Cœur

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20200207010831.9046-41-philmd@redhat.com \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox